<?php
/***************************************************************************
 *                          lang_faq.php [romn]
 *                            -------------------
 *   begin                : Aug 7, 2002
 *   last update          : Dec 31, 2004
 *   language version     : 6.0
 *   copyright            : Romanian phpBB online community
 *   website              : http://www.phpbb.ro
 *   copyright 1          : (C) Robert Munteanu
 *   email     1          : rombert@go.ro
 *   copyright 2          : (C) Bogdan Toma
 *   email     2          : bogdan@phpbb.ro
 *
 *   $Id: lang_faq.php,v 1.4 2001/12/15 16:42:08 psotfx Exp $
 *
 *
 ***************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/
 
// 
// To add an entry to your FAQ simply add a line to this file in this format:
// $faq[] = array("question", "answer");
// If you want to separate a section enter $faq[] = array("--","Block heading goes here if wanted");
// Links will be created automatically
//
// DO NOT forget the ; at the end of the line.
// Do NOT put double quotes (") in your FAQ entries, if you absolutely must then escape them ie. \"something\";
//
// The FAQ items will appear on the FAQ page in the same order they are listed in this file
//
 
  
$faq[] = array("--","Probleme de autentificare i nregistrare");
$faq[] = array("De ce nu m pot autentifica?", "V-ai nregistrat? Serios vorbind, trebuie s v nregistrai pentru a v autentifica. Ai fost exclus de pe site (un mesaj v apare pentru a v indica acest lucru) ? Dac da, ar trebui s contactai adminstratorul site-ului sau forumului pentru a afla motivul. Dac suntei nregistrat i nu suntei exclus i tot nu v putei autentifica, atunci verificai foarte bine numele de utilizator i parola. De obicei, aceasta este problema. Dac nici aceasta nu este soluia, luai legtura cu administratorul forumului pentru c forumul ar putea fi incorect configurat.");
$faq[] = array("De ce trebuie s m nregistrez?", "S-ar putea s nu fie nevoie, depinde de adminstratorul forumului dac e nevoie s v nregistrai sau nu. Oricum, nregistrarea v va oferi acces la opiuni care nu sunt disponibile utilizatorilor anonimi cum ar fi imagini asociate, mesaje private, trimiterea de email-uri altor utilizatori, nscrierea n grupuri  etc. Dureaz doar cteva momente s v nregistrai , aa c v recomandm s v nregistrai.");
$faq[] = array("De ce sunt scos afar din forum automat?", "Dac nu activai opiunea <i>Autentific-m automat la fiecare vizit</i>, atunci cnd v autentificai vei fi autentificat doar pentru o perioad prestabilit. Aceast msur previne ca cineva s se foloseasc de contul dumneavoastr. Pentru a rmne autentificat, bifai aceast opiune la autentificare, dar acest lucru nu este recomandat dac accesai forumul de la un calculator utilizat de mai multe persoane, cum ar fi de la o bibliotec, cafenea internet, facultate etc");
$faq[] = array("Cum fac s nu mi apar numele de utilizator pe listele de utilizatori conectai?", "n profilul dumneavoastr vei gsi o opiune <i>Ascundei indicatorul de conectare</i>, i dac vei seta aceast opiune pe <i>Da</i> vei fi vizibil doar pentru administratori i pentru dumneavoastr. Vei fi numrat ca utilizator ascuns.");
$faq[] = array("Mi-am pierdut parola!", "Nu intrai n panic! Parola dumneavoastr nu poate fi refcut, dar poate fi resetat. Pentru a realiza acest lucru, mergei la pagina de autentificare i folosii legtura <i>Mi-am uitat parola</i>, urmai instruciunile i ar trebui s putei s v autentificai n scurt timp.");
$faq[] = array("Sunt nregistrat dar nu m pot autentifica!", "Mai inti verificai dac ai introdus numele de utilizator i parola corect. Dac sunt corecte, atunci fie, dac este activat opiunea COPPA i ai dat bifat <i>Sunt de acord cu aceste condiii i declar c am sub 13 ani</i> la nregistrare, va trebui s urmai instruciunile primite, fie contul dumneavoastr trebuie s fie activat. Unele forumuri oblig ca toi utilizatori noi s i activeze conturile , fie ctre dumneavoastr personal, fie de ctre administrator nainte de a v putei autentifica. Cnd v-ai nregistrat ai fi aflat dac este necesar activarea. Dac ai primit un email atunci urmai instruciunile. Dac nu, suntei sigur c ai specificat corect adresa de mail ? Unul din motivele pentru care activarea este folosit este pentru a preveni abuzul de ctre utilizatori <i>pirat</i> anonimi. Daca suntei sigur c adresa de mail folosit este corect atunci ncercai s contactai administratorul.");
$faq[] = array("M-am nregistrat cu ceva timp n urm dar nu m mai pot autentifica?!", "Cele mai probabile motive sunt: ai folosit un nume de utilizator inexistent sau o parol greit (verificai-v email-ul pe care l-ai primit cnd v-ai nregistrat) sau administratorul a ters contul dumneavoastr dintr-un motiv sau altul. Dac motivul este al doilea, atunci poate nu ai scris nici un mesaj ? Se obinuiete ca forumurile s exclud periodic utilizatorii care nu au scris nimic pentru a reduce mrimea bazei de date. ncercai s v nregistrai din nou i s v implicai n discuii.");


$faq[] = array("--","Preferine i setri");
$faq[] = array("Cum mi schimb setrile?", "Toate setrile dumneavoastr (dac suntei nregistrat) sunt stocate n baza de date. Pentru a le schimba folosii legtura <i>Profil</i> (n general afiat n partea superioar a paginilor dar nu ntotdeauna). Acest lucru v va permite s v schimbai toate setrile.");
$faq[] = array("Orele nu sunt corecte!", "Orele sunt aproape sigur corecte, dar ceea ce dumneavoastr s-ar putea s vedei c toate orele afiate sunt ntr-o zon cu fus orar diferit fa de cea n care suntei. Dac este aa, ar trebui s v schimbai setarea din profil pentru zona de fus orar n care suntei, cum ar fi Bucureti, Londra, Paris, etc. V rugm, s observai c schimbarea zonei de fus orar, ca majoritatea setrilor, poate fi fcut doar de utilizatorii nregistrai. Deci dac nu suntei nregistrat, acesta este un moment bun s o facei, dac mi permitei jocul de cuvinte!");
$faq[] = array("Am schimbat zona de fus orar i ora tot este greita!", "Dac suntei sigur c ai setat zona de fus orar corect i ora nca este diferit, cel mai probabil rspuns este ora de var. Programul nu a fost gndit s se plieze dup schimbrile fcute ntre ora standard i cea de var aa c n timpul lunilor de var ora poate fi diferit cu 60 de minute fa de cea local real.");
$faq[] = array("Limba mea nu este n list!", "Cele mai probabile motive sunt fie c administratorul nu a instalat limba dumneavoastr sau c cineva nu a tradus nca acest program n limba dumneavoastr. ncercai s l ntrebai pe administrator dac poate instala limba de care avei nevoie i dac nu exist, atunci suntei liber s creai o nou traducere. Mai multe informaii pot si gasite pe site-ul grupului phpBB. Urmrii legtura din partea inferioar  paginilor)");
$faq[] = array("Cum pot afia o imagine sub numele meu de utilizator?", "Pot fi dou imagini sub numele de utilizator cnd vizualizai mesajele. Prima este o imagine asociata cu rangul dumneavoastr, n general acestea lund forma de stele sau blocuri indicnd cte mesaje ai scris sau statutul dumneavoastr pe forumuri. Sub aceasta ar putea fi o imagine mai mare cunoscut sub numele de <i>avatar</i> (imagine asociat). Aceasta este, n general, unic sau personal fiecrui utilizator. Administratorul decide dac s activeze imaginile asociate i au posibilitatea de a alege modalitatea prin care imaginile asociate pot fi folosite. Dac nu putei folosi imaginile asociate, atunci aceasta este decizia administratorului i ar trebui s-l ntrebai pe acesta despre motivele care au dus la aceast decizie (suntem siguri c vor fi ntemeiate!)");
$faq[] = array("Cum mi schimb rangul?", "n general nu putei schimba direct rangurile (rangul apare direct sub numele dumneavoastr de utilizator, n mesaje i n profilul dumneavoastr, depinde de stilul folosit). Majoritatea forumurilor folosesc rangurile pentru a indica numrul de mesaje pe care le-ai scris i pentru a identifica anumii utilizatori, cum ar fi moderatorii i administratorii. V rugm, s nu abuzai de forum scriind mesaje inutile doar pentru a v crete rangul, pentru c probabil vei descoperi ca moderatorul sau administratorul v va scdea pur i simplu numrul de mesaje scrise.");
$faq[] = array("De ce cnd folosesc legtura de email al unui utilizator mi cere s m autentific?", "Doar utilizatorii nregistrai pot trimite mesaje altor utilizatori prin formularul ncorporat de mail (dac administratorul permite acest lucru). Acest lucru se ntampl pentru a preveni folosirea maliioasa a sistemului de mesagerie de ctre utilizatorii anonimi.");


$faq[] = array("--","Probleme de scriere/publicare a mesajelor");
$faq[] = array("Cum deschid un subiect n forum?", "Simplu. Apasai pe butonul specific, fie din forum, fie pe ecranul cu subiecte. Este posibil s fie nevoie s v nregistrai nainte de a scrie un mesaj. Facilitile care v sunt disponibile sunt trecute n partea de jos a ecranului (de genul <i>Putei crea un subiect nou n acest forum</i> )");
$faq[] = array("Cum pot modifica sau terge un mesaj?", "n afara cazului n care suntei administratorul forumului sau moderatorul, putei modifica sau terge doar mesajele dumneavoastr. Putei modifica un mesaj (uneori doar pentru o scurta perioad dup publicare) apsnd butonul <i>modific</i> pentru mesajul respectiv. Vei observa o mic seciune de text sub mesaj cnd revenii la subiect. Aceasta arat de cate ori l-ai modificat. Aceasta va aprea doar dac nimeni nu v-a rspuns. De asemenea, nu va aprea dac moderatorii sau administratorii modific mesajul (acetia ar trebui s lase un mesaj n care s spun ce au modificat i de ce). Observai c utilizatorii normali nu pot modifica un mesaj odat ce cineva a rspuns.");
$faq[] = array("Cum pot s mi adaug semnatura la mesaj?", "Pentru a adauga o semnatur trebuie nti s v creai una, lucru pe care l putei face accesandu-v profilul. Odat ce semntura este creat, putei s bifai opiunea <i>Adaug semnatura</i> de pe formularul de publicare pentru a v aduga semntura. Putei, de asemenea, s v adugai direct semntura la toate mesajele bifnd opiunea corespunzatoare din profil (putei s prevenii adugarea semnturii unor anumite mesaje dac tergei bifa respectiv din formularul de publicare)");
$faq[] = array("Cum pot crea un sondaj?", "Este uor s creai un sondaj. Cnd creai un subiect nou (sau modificai primul mesaj al unui subiect, dac avei permisiunea), ar trebui s vedei o seciune <i>Adaug un chestionar</i> sub zona principal de publicare (dac nu vedei acest lucru probabil c nu avei privilegiile de acces necesare pentru a crea sondaje). Ar trebui s introducei un titlu pentru chestionar i cel puin dou opiuni (pentru a alege o opiune scriei ntrebarea sondajului i apsai pe butonul <i>Adaug o opiune</i>). Putei s schimbai i valabilitatea sondajului, unde perioada 0 nseamn un sondaj perpetuu. Va exista i o limita a numrului de opiuni pe care l putei folosi, specificat de ctre administrator.");
$faq[] = array("Cum modific sau terg un sondaj?", "Ca i n cazul mesajelor, sondajele pot fi modificate doar de autor, de moderator sau de un administrator. Pentru a modifica un sondaj efectuai un click pe primul mesaj din cadrul subiectului (acesta este ntotdeauna asociat cu sondajul). Dac nimeni nu a votat, atunci poate fi ters sau modificat, ns dac cineva a votat deja, doar moderatorul sau administratorul poate modifica sau terge sondajul. Acest lucru previne sabotarea sondajelor sau schimbarea inoportun a opiunilor."); 
$faq[] = array("De ce nu pot s accesez un forum?", "Unele forumuri pot fi limitate pentru anumii utilizatori sau grupuri. Pentru a vedea, citi, publica, etc. este nevoie probabil de autorizaie special pe care o pot acorda doar moderatorul forumului i administratorul. Ar trebui s luai legatura cu ei.");
$faq[] = array("De ce nu pot vota n sondaje?", "Doar utilizatorii nregistrai pot vota n sondaje (pentru a preveni falsificarea rezultatelor). Daca v-ai nregistrat i tot nu putei vota atunci probabil c nu avei drepturile de acces necesare.");


$faq[] = array("--","Formatri i tipuri de mesaje");
$faq[] = array("Ce este codul BB?", "Codul BB este o implementare special a HTML-ului. Posibilitatea de a folosi codul BB este dat de decizia administratorului (putei dezactiva acest cod de la mesaj la mesaj din formularul de publicare). Codul BB este similar ca stil cu HTML-ul, balizele (tag-urile) sunt nchise n paranteze ptrate [ i ] mai degrab dect &lt; i &gt; i ofer un control mai bun asupra a ce i cum se afieaz. Pentru mai multe informaii despre codul BB, consultai ghidul care poate fi accesat de pe pagina de publicare.");
$faq[] = array("Pot folosi HTML?", "Acest lucru depinde de administrator, care are control complet. Dac v este permis s l folosii, probabil c vei descoperi c doar cteva balize funcioneaz. Aceasta este o masur de <i>securitate</i> pentru a prentampina abuzurile care ar duce la distrugerea aezrii n pagin sau ar cauza alte probleme. Daca HTML este activat, l putei dezactiva de la mesaj la mesaj din formularul de publicare.");
$faq[] = array("Ce sunt <i>Zmbetele</i>?", "Zmbetele sau iconiele emotive sunt imagini mici care pot fi folosite pentru a exprima anumite sentimente folosind un cod scurt. Spre exemplu :) nseamn vesel , :( nseamn trist. Lista complet poate fi vazut n formularul de publicare. ncercai totui s nu i folosii prea mult pentru c pot face un mesaj ilizibil i un moderator se poate hotr s i scoat din mesaj sau s tearg mesajul cu totul.");
$faq[] = array("Pot publica imagini?", "Imaginile pot fi afiate n mesajele dumneavoastr. Cu toate acestea, nu exist nici o posibilitate n acest forum pentru ncarcarea imaginilor direct n forum. De aceea, trebuie s scriei o legatur ctre o imagine stocat pe un server accesibil publicului, cum ar fi <i>http://un.server.oarecare.ro/imaginea-mea.gif</i>. Nu putei s facei legatura cu imagini de pe calculatorul dumneavoastr (doar dac este un server), nici cu imagini stocate n spatele unui mecanism de autentificare, cum ar fi casuele de mail, site-uri protejate cu parol, etc. Pentru a afia imaginea, folosii fie baliza codului BB [img] sau cod HTML (dac este permis).");
$faq[] = array("Ce sunt anunurile?" ,"Anunurile deseori conin informaii importante i ar trebui s le citii ct de repede putei. Anunurile apar n partea de sus a fiecrei pagini n forumul de care aparin. Dac putei sau nu posta un anun depinde de permisiunile necesare, care sunt stabilite de administrator.");             
$faq[] = array("Ce sunt subiectele importante?", "Subiectele importante apar sub anunuri n forum i doar pe prima pagin. Deseori sunt destul de importante i ar trebui s le citii dac putei. Ca i cu anunurile, administratorul alege ce permisiuni sunt necessre pentru pentru a le publica.");
$faq[] = array("Ce sunt subiectele blocate?", "Subiectele sunt blocate fie de ctre moderator, fie de ctre administrator. Nu putei rspunde unui subiect blocat i orice chestionar coninut este nchis automat. Subiectele pot fi nchise din mai multe motive.");


$faq[] = array("--","Niveluri de utilizatori i grupuri");
$faq[] = array("Cine sunt administratorii?", "Administratorii sunt cei care au cel mai mare nivel de control asupra ntregului forum. Aceti utilizatori controleaz toate detaliile forumurilor, ncluznd permisiunile de acces, excluderea utilizatorilor, crearea grupurilor i a moderatorilor, etc. De asemenea, au capacitatea de a modera toate formurile.");
$faq[] = array("Cine sunt moderatorii?", "Moderatorii sunt persoane (sau grupuri de persoane) a cror menire este s aib grij de forumuri n mod constant. Au permisiunea de a modifica sau terge mesajele i de a bloca, debloca, muta, terge i mpri subiectele de discuie n forumurile pe care le modereaz. n mod general, moderatorii exist pentru a avea grij ca utilizatorii s nu scrie \"pe lng subiect\" i s nu scrie materiale abuzive sau ofensatoare.");
$faq[] = array("Ce sunt grupurile de utilizatori?", "Grupurile de utilizatori sunt o modalitate de grupare a utilizatorilor. Fiecare utilizator poate aparine mai multor grupuri (acest lucru difer de majoritatea celorlalte programe) i fiecare grup are drepturi de acces individuale. Acest lucru uureaz munca administratorilor dac doresc ca mai muli utilizatori s modereze un forum sau s le ofere acces ntr-un forum privat.");
$faq[] = array("Cum pot s fac parte dintr-un grup de utilizatori?", "Pentru a intra ntr-un grup folosii legatura de <i>Grupuri de utilizatori</i> din partea de sus a paginii (acest lucru poate fi diferit de la pagin la pagin). Nu toate grupurile sunt deschise, unele sunt nchise i altele pot fi chiar ascunse. Dac grupul o permite, putei s cerei s fii nscris apsnd butonul respectiv. Moderatorul va trebui s v aprobe cererea. Este posibil s v ntrebe care sunt motivele pentru care v dorii s intrai n grup. V rugm s nu hruii un moderator de grup dac v respinge cererea pentru c are motive ntemeiate.");
$faq[] = array("Cum pot deveni moderatorul unui grup de utilizatori?", "Grupurile de utilizatori sunt create de ctre administrator i n acel moment este numit un moderator. Dac dorii s creai un grup de utilizatori atunci primul lucru pe care trebuie s l facei este s luai legatura cu administratorul.");


$faq[] = array("--","Mesaje private");
$faq[] = array("Nu pot trimite mesaje private!", "Exist trei posibile motive: nu suntei nregistrat i/sau autentificat, administratorul nu a activat mesajele private pentru toi utilizatorii sau administratorul a restricionat pentru dumneavoastr folosirea mesajelor private. n ultimul caz ar trebui s l intrebai ce motive a avut.");
$faq[] = array("Tot primesc mesaje private nedorite!", "n viitor vom adauga o list de persoane ale cror mesaje s fie ignorate. Deocamdat dac primii n continuare aceste mesaje anunai administratorul, pentru c el are posibilitatea de a opri un utilizator s trimit mesaje private.");
$faq[] = array("Am primit spam-uri sau mesaje abuzive de la cineva din forum!", "Ne pare ru s auzim acest lucru. Formularul pentru trimiterea unui mesaj include msuri de siguran pentru a observa care utilizatori trimit astfel de mesaje. Ar trebui s trimitei administratorului o copie complet a mesajului primit, inclusiv antetul (acestea ofer detalii despre utilizatorul care a trimis mesajul). Astfel, el poate aciona.");

//
// These entries should remain in all languages and for all modifications
//
$faq[] = array("--","ntrebri despre phpBB 2");
$faq[] = array("Cine a scris acest program?", "Acest program (n forma nemodificat) este produs, lansat i aflat sub copyright-ul <a href=\"http://www.phpbb.com/\" target=\"_blank\">grupului phpBB</a>. Este disponibil sub Licena General Public GNU i poate fi distribuit liber; folosii legtura ctre grup mai multe detalii.");
$faq[] = array("De ce nu este facilitatea X disponibil?", "Acest program a fost scris i liceniat de ctre grupul phpBB. n cazul n care considerai c o facilitate trebuie s fie adaugat, v rugm s vizitai site-ul phpBB.com i s vedei ce are de spus grupul phpBB. V rugm s nu publicai cereri de faciliti pe forumurile de la phpbb.com, pentru c grupul phpBB folosete sourceforge pentru a delega sarcinile legate de noile faciliti. V rugm s trecei prin aceste forumuri i s vedei, dac exist, care este poziia noastr legat de o facilitate i s urmai procedura explicat acolo.");
$faq[] = array("Cu cine iau legatura pentru probleme legate de abuzuri i/sau juridice legate de acest program?", "Ar trebui s luai legatura cu administratorul forumului. Dac nu putei s facei acest lucru, ar trebui s ncercai cu unul din moderatorii de forumuri i s i intrebai cu cine ai putea lua legatura. Dac tot nu primii rspuns, ar trebui s luai legtura cu posesorul domeniului dumneavoastr (efectuai o interogare whois) sau, dac acesta este pe un domeniu gratuit (yahoo, free.fr, etc.), conducerea sau departamentul pentru abuzuri. Grupul phpBB nu are absolut nici un fel de control i nu poate fi tras la rspundere pentru cum, unde sau de ctre cine este folosit acest program. Este inutil s luai legatura cu grupul phpBB pentru orice fel de probleme juridice care nu sunt legate direct de pagina phpbb.com sau de program n sine. Dac trimitei un mesaj ctre grupul phpBB despre orice folosire a unui ter a acestui program, nu ateptai un rspuns pentru c nu vei primi.");

//
// This ends the FAQ entries
//

?>